==> mineral-1.0.0.tar.gz: lib/api.dart <==
/// The api is the Map of all the classes, enumerations of the framework
library api;

export 'src/api/client/mineral_client.dart' show MineralClient, ClientActivity, ClientStatus;
export 'src/api/client/client_presence.dart' show ClientPresence, GamePresence;

export 'src/api/application.dart' show Application;
export 'src/api/user.dart' show User;
export 'src/api/status.dart' show Status, StatusType;
export 'src/api/activity.dart' show Activity;
export 'src/api/guilds/guild_member.dart' show GuildMember;
export 'src/api/managers/member_role_manager.dart' show MemberRoleManager;
export 'src/api/managers/voice_manager.dart' show VoiceManager;

export 'src/api/guilds/guild.dart' show Guild;
export 'src/api/guilds/guild_preview.dart' show GuildPreview;
export 'src/api/moderation_rule.dart' show ModerationEventType, ModerationTriggerType, ModerationPresetType, ModerationActionType, ModerationTriggerMetadata, ModerationActionMetadata, ModerationAction, ModerationRule;

export 'src/api/guilds/guild_scheduled_event.dart' show ScheduledEventStatus, ScheduledEventEntityType, GuildScheduledEvent, ScheduledEventUser;

export 'src/api/webhook.dart' show Webhook;

export 'src/internal/managers/IntentManager.dart' show Intent;

export 'src/api/channels/channel_builder.dart' show ChannelBuilder;

export 'src/api/channels/voice_channel.dart' show VoiceChannel;
export 'src/api/channels/text_channel.dart' show TextChannel;
export 'src/api/channels/text_based_channel.dart' show TextBasedChannel;
export 'src/api/channels/partial_text_channel.dart' show PartialTextChannel;
export 'src/api/channels/guild_channel.dart' show GuildChannel;
export 'src/api/channels/category_channel.dart' show CategoryChannel;
export 'src/api/channels/partial_channel.dart' show PartialChannel, ChannelType;
export 'src/api/permission_overwrite.dart' show PermissionOverwrite, PermissionOverwriteType;

export 'src/api/messages/message.dart' show Message;
export 'src/api/messages/embed_builder.dart' show EmbedBuilder, Footer, Image, Thumbnail, Author, Field;
export 'src/api/color.dart' show Color;

export 'src/api/emoji.dart' show EmojiBuilder, Emoji;
export 'src/api/role.dart' show Role;

export 'src/api/components/row_builder.dart' show RowBuilder;
export 'src/api/components/select_menu_builder.dart' show SelectMenuBuilder, SelectMenuOption, EmojiOption;
export 'src/api/components/modal_builder.dart' show ModalBuilder;
export 'src/api/components/text_input_builder.dart' show TextInputBuilder, TextInputStyle;
export 'src/api/components/button_builder.dart' show ButtonBuilder, ButtonStyle;
export 'src/api/components/link_builder.dart' show LinkBuilder;

export 'src/api/interactions/command_interaction.dart' show CommandInteraction;
export 'src/api/interactions/button_interaction.dart' show ButtonInteraction;
export 'src/api/interactions/modal_interaction.dart' show ModalInteraction;
export 'src/api/interactions/select_menu_interaction.dart' show SelectMenuInteraction;
export 'src/api/interactions/context_user_interaction.dart' show ContextUserInteraction;
export 'src/api/interactions/context_message_interaction.dart' show ContextMessageInteraction;
export 'src/api/interactions/interaction.dart' show Interaction;

export 'src/api/utils.dart';
export 'src/internal/extensions/collection.dart';
export 'src/internal/extensions/string.dart';

typedef Snowflake = String;

==> mineral-1.0.6.tar.gz: lib/api.dart <==
/// The api is the Map of all the classes, enumerations of the framework
library api;

export 'src/api/client/mineral_client.dart' show MineralClient, ClientActivity, ClientStatus;
export 'src/api/client/client_presence.dart' show ClientPresence, GamePresence;

export 'src/api/application.dart' show Application;
export 'src/api/user.dart' show User;
export 'src/api/status.dart' show Status, StatusType;
export 'src/api/activity.dart' show Activity;
export 'src/api/guilds/guild_member.dart' show GuildMember;
export 'src/api/managers/member_role_manager.dart' show MemberRoleManager;
export 'src/api/managers/voice_manager.dart' show VoiceManager;

export 'src/api/guilds/guild.dart' show Guild;
export 'src/api/guilds/guild_preview.dart' show GuildPreview;
export 'src/api/moderation_rule.dart' show ModerationEventType, ModerationTriggerType, ModerationPresetType, ModerationActionType, ModerationTriggerMetadata, ModerationActionMetadata, ModerationAction, ModerationRule;

export 'src/api/guilds/guild_scheduled_event.dart' show ScheduledEventStatus, ScheduledEventEntityType, GuildScheduledEvent, ScheduledEventUser;

export 'src/api/webhook.dart' show Webhook;

export 'src/internal/managers/intent_manager.dart' show Intent;

export 'src/api/channels/channel_builder.dart' show ChannelBuilder;

export 'src/api/channels/voice_channel.dart' show VoiceChannel;
export 'src/api/channels/text_channel.dart' show TextChannel;
export 'src/api/channels/text_based_channel.dart' show TextBasedChannel;
export 'src/api/channels/partial_text_channel.dart' show PartialTextChannel;
export 'src/api/channels/guild_channel.dart' show GuildChannel;
export 'src/api/channels/category_channel.dart' show CategoryChannel;
export 'src/api/channels/partial_channel.dart' show PartialChannel, ChannelType;
export 'src/api/permission_overwrite.dart' show PermissionOverwrite, PermissionOverwriteType;

export 'src/api/messages/message.dart' show Message;
export 'src/api/messages/embed_builder.dart' show EmbedBuilder, Footer, Image, Thumbnail, Author, Field;
export 'src/api/color.dart' show Color;

export 'src/api/emoji.dart' show EmojiBuilder, Emoji;
export 'src/api/role.dart' show Role;

export 'src/api/components/row_builder.dart' show RowBuilder;
export 'src/api/components/select_menu_builder.dart' show SelectMenuBuilder, SelectMenuOption, EmojiOption;
export 'src/api/components/modal_builder.dart' show ModalBuilder;
export 'src/api/components/text_input_builder.dart' show TextInputBuilder, TextInputStyle;
export 'src/api/components/button_builder.dart' show ButtonBuilder, ButtonStyle;
export 'src/api/components/link_builder.dart' show LinkBuilder;

export 'src/api/interactions/command_interaction.dart' show CommandInteraction;
export 'src/api/interactions/button_interaction.dart' show ButtonInteraction;
export 'src/api/interactions/modal_interaction.dart' show ModalInteraction;
export 'src/api/interactions/select_menu_interaction.dart' show SelectMenuInteraction;
export 'src/api/interactions/context_user_interaction.dart' show ContextUserInteraction;
export 'src/api/interactions/context_message_interaction.dart' show ContextMessageInteraction;
export 'src/api/interactions/interaction.dart' show Interaction;

export 'src/api/utils.dart';
export 'src/internal/extensions/collection.dart';
export 'src/internal/extensions/string.dart';

typedef Snowflake = String;
